"""Extended data-structure toolkit — PriorityQueue, Trie, LRUCache, etc."""

from .core import PriorityQueue, Trie, LRUCache, CircularBuffer

__version__ = "0.1.0"
__all__ = ["PriorityQueue", "Trie", "LRUCache", "CircularBuffer"]

